@@ -4,7 +4,6 @@ from rs_datasets.netflix import Netflix
 from rs_datasets.lastfm import Lastfm
 from rs_datasets.epinions import Epinions
 from rs_datasets.goodreads import Goodreads
-from rs_datasets.dating_agency import DatingAgency
 from rs_datasets.book_crossing import BookCrossing
 from rs_datasets.jester import Jester
 from rs_datasets.amazon import Amazon
@@ -12,5 +11,5 @@ from rs_datasets.rekko import Rekko
 from rs_datasets.steam import Steam
 from rs_datasets.anime import Anime
 from rs_datasets.retail_rocket import RetailRocket
-from rs_datasets.youchoose import YooChoose
+from rs_datasets.yoochoose import YooChoose
 from rs_datasets.diginetica import Diginetica
